@@ -1,4 +1,4 @@
-/* $Id: rapi_indirection.c 2509 2006-07-03 21:08:59Z oleavr $ */
+/* $Id: rapi_indirection.c 3116 2007-12-23 14:01:55Z gdiepen $ */
 #undef __STRICT_ANSI__
 #define _GNU_SOURCE
 #include "rapi_indirection.h"
@@ -87,6 +87,15 @@ DWORD CeSetFilePointer(
     dwMoveMethod );
 }
 
+#if 0
+BOOL CeSetEndOfFile(
+        HANDLE hFile)
+{
+    RapiContext * context = rapi_context_current();
+    return ( *context->rapi_ops->CeSetEndOfFile ) ( hFile );
+}
+#endif
+
 BOOL CeGetFileTime(
         HANDLE hFile,
     LPFILETIME lpCreationTime,
@@ -529,6 +538,24 @@ LONG CeRegDeleteValue(
 }
 
 
+
+DWORD CeGetDiskFreeSpaceEx(
+		LPCTSTR _lpDirectoryName, 
+		PULARGE_INTEGER lpFreeBytesAvailable, 
+		PULARGE_INTEGER lpTotalNumberOfBytes, 
+		PULARGE_INTEGER lpTotalNumberOfFreeBytes)
+{
+    RapiContext * context = rapi_context_current();
+    return ( *context->rapi_ops->CeGetDiskFreeSpaceEx ) (
+			_lpDirectoryName,
+			lpFreeBytesAvailable,
+			lpTotalNumberOfBytes,
+			lpTotalNumberOfFreeBytes
+    );
+}
+
+
+
 LONG CeRegQueryInfoKey(
         HKEY hKey,
     LPWSTR lpClass,
