@@ -1,4 +1,4 @@
-/* $Id: rapi_buffer.h 2401 2006-04-17 23:32:03Z oleavr $ */
+/* $Id: rapi_buffer.h 3080 2007-12-13 20:42:45Z mark_ellis $ */
 #ifndef __rapi_buffer_h__
 #define __rapi_buffer_h__
 
@@ -158,5 +158,22 @@ bool rapi_buffer_read_find_data(
         RapiBuffer* buffer,
         LPCE_FIND_DATA lpFindFileData);
 
+
+/**
+ * Dump the complete buffer that is supplied as parameter
+ */
+void rapi_buffer_debug_dump_buffer(
+		char* desc, 
+		RapiBuffer* buffer) ;
+
+/**
+ * Dump the remainder of the buffer that is supplied as 
+ * a parameter. Mostly of use when dumping the recv buffer
+ */
+void rapi_buffer_debug_dump_buffer_from_current_point(
+		char* desc, 
+		RapiBuffer* buffer) ;
+
+
 #endif
 
