@@ -1,4 +1,4 @@
-/* $Id: rapi_context.c 2575 2006-09-20 18:11:36Z voc $ */
+/* $Id: rapi_context.c 3373 2008-04-11 09:52:55Z mark_ellis $ */
 #undef __STRICT_ANSI__
 #define _GNU_SOURCE
 #include "rapi_context.h"
@@ -9,6 +9,11 @@
 #include <signal.h>
 #include <errno.h>
 
+#define USE_THREAD_SAFE_VERSION 1
+#ifdef USE_THREAD_SAFE_VERSION
+#include <pthread.h>
+#endif
+
 #define CERAPI_E_ALREADYINITIALIZED  0x8004101
 
 #define RAPI_PORT  990
@@ -24,28 +29,96 @@
 #endif
 #define rapi_context_error(args...)    synce_error(args)
 
+
+
+#ifdef USE_THREAD_SAFE_VERSION
+/*This holds the value for the key where the contexts are stored*/
+static pthread_key_t context_key = -1;
+/*This makes sure that the a key is created only once, we can also use pthread for this*/
+static pthread_once_t key_is_created = PTHREAD_ONCE_INIT;
+#else
 static RapiContext* current_context;
 
+#endif
+
+
 extern struct rapi_ops_s rapi_ops;
 extern struct rapi_ops_s rapi2_ops;
 
+
+#ifdef USE_THREAD_SAFE_VERSION
+/* This method will create a key to hold the context_key
+ * with which each thread can access the thread local 
+ * rapi_context.
+ * It must be called ONLY once, there for this method
+ * will always be used in combination with the 
+ * pthread_once method.
+ * Do not run it multiple times, this will result in 
+ * unpredictable behaviour and might crash things!
+ */
+void create_pthread_key(){
+	pthread_key_create( &context_key, NULL ) ;
+}
+#endif
+
+
+
+
+
+
+
+
+
 RapiContext* rapi_context_current()/*{{{*/
 {
-	/* TODO: make thread-safe version of this with thread private variables */
+#ifdef USE_THREAD_SAFE_VERSION
+	/* If the key for the thread_local context variables was not initalized yet,
+	 * do that now
+	 */
+	(void) pthread_once(&key_is_created, create_pthread_key);
 
-	if (!current_context)
+	/* Get the thread local current_context */
+	RapiContext* thread_current_context = (RapiContext*)pthread_getspecific(context_key) ;
+
+	/* If the thread local context is not initialized, setup a new one
+	 * DON'T forget to reload the thread local information that is updated 
+	 * by the rapi_context_set(rapi_context_new())!
+	 */
+	if (!thread_current_context)
 	{
 		rapi_context_set(rapi_context_new());
+		thread_current_context = (RapiContext*)pthread_getspecific(context_key) ;
+	}
+	
+	return thread_current_context;
+#else
+	if (!current_context)
+	{
+			rapi_context_set(rapi_context_new());
 	}
 
 	return current_context;
+#endif
+
 }/*}}}*/
 
 void rapi_context_set(RapiContext* context)
 {
-  current_context = context;
+#ifdef USE_THREAD_SAFE_VERSION
+	/* If the key for the thread_local context variables was not initalized yet,
+	 * do that now
+	 */
+	(void) pthread_once(&key_is_created, create_pthread_key);
+	
+	/* Set the context for this thread in its local thread variable */
+	pthread_setspecific(context_key, (void*) context ) ;
+#else
+	current_context = context;
+#endif
 }
 
+
+
 RapiContext* rapi_context_new()/*{{{*/
 {
 	RapiContext* context = calloc(1, sizeof(RapiContext));
@@ -101,26 +174,28 @@ HRESULT rapi_context_connect(RapiContext* context)
 		goto fail;
 	}
 
-	if (!info->dccm_pid)
-	{
-		synce_error("DCCM PID entry not found for current connection");
-		goto fail;
-	}
+    if (info->transport == NULL || ( strcmp(info->transport, "odccm") != 0 && strcmp(info->transport, "hal") != 0 ) ) {
+        if (!info->dccm_pid)
+        {
+            synce_error("DCCM PID entry not found for current connection");
+            goto fail;
+        }
 
-	if (kill(info->dccm_pid, 0) < 0)
-	{
-		if (errno != EPERM)
-		{
-			synce_error("DCCM not running with pid %i", info->dccm_pid);
-			goto fail;
-		}
-	}
+        if (kill(info->dccm_pid, 0) < 0)
+        {
+            if (errno != EPERM)
+            {
+                synce_error("DCCM not running with pid %i", info->dccm_pid);
+                goto fail;
+            }
+        }
 
-	if (!info->ip)
-	{
-		synce_error("IP entry not found for current connection");
-		goto fail;
-	}
+        if (!info->ip)
+        {
+            synce_error("IP entry not found for current connection");
+            goto fail;
+        }
+    }
 
     if (info->transport == NULL || strncmp(info->transport,  "ppp", 3) == 0) {
         if ( !synce_socket_connect(context->socket, info->ip, RAPI_PORT) )
@@ -156,12 +231,20 @@ HRESULT rapi_context_connect(RapiContext* context)
         }
         context->rapi_ops = &rapi_ops;
     } else {
-        if ( !synce_socket_connect_proxy(context->socket, info->ip) )
+        if (strcmp(info->transport, "odccm") == 0 || strcmp(info->transport, "hal") == 0) {
+            synce_socket_take_descriptor(context->socket, info->fd);
+        }
+        else if ( !synce_socket_connect_proxy(context->socket, info->ip) )
         {
             synce_error("failed to connect to proxy for %s", info->ip);
             goto fail;
         }
-        context->rapi_ops = &rapi2_ops;
+
+	/* rapi 2 seems to be used on devices with OS version of 5.1 or greater */
+	if ((info->os_version > 4) && (info->os_minor > 0))
+	  context->rapi_ops = &rapi2_ops;
+	else
+	  context->rapi_ops = &rapi_ops;
     }
 
 	context->is_initialized = true;
