@@ -1,4 +1,4 @@
-/* $Id: pcp.c 2348 2006-04-05 14:58:44Z twogood $ */
+/* $Id: pcp.c 3321 2008-03-20 09:44:20Z mark_ellis $ */
 #include "pcommon.h"
 #include <rapi.h>
 #include <synce_log.h>
@@ -7,14 +7,14 @@
 #include <string.h>
 #include <unistd.h>
 
-char* devpath = NULL;
+char* dev_name = NULL;
 
 static void show_usage(const char* name)
 {
 	fprintf(stderr,
 			"Syntax:\n"
 			"\n"
-			"\t%s [-d LEVEL] [-p DEVPATH] [-h] SOURCE DESTINATION\n"
+			"\t%s [-d LEVEL] [-p DEVNAME] [-h] SOURCE DESTINATION\n"
 			"\n"
 			"\t-d LEVEL     Set debug log level\n"
 			"\t                 0 - No logging (default)\n"
@@ -22,7 +22,7 @@ static void show_usage(const char* name)
 			"\t                 2 - Errors and warnings\n"
 			"\t                 3 - Everything\n"
 			"\t-h           Show this help message\n"
-                        "\t-p DEVPATH   Device path\n"
+                        "\t-p DEVNAME   Mobile device name\n"
 			"\tSOURCE       The source filename\n"
 			"\tDESTINATION  The destination filename\n",
 			name);
@@ -43,7 +43,7 @@ static bool handle_parameters(int argc, char** argv, char** source, char** dest)
 				break;
 
                         case 'p':
-                                devpath = optarg;
+                                dev_name = optarg;
                                 break;
 			
 			case 'h':
@@ -75,7 +75,7 @@ static bool remote_copy(const char* ascii_source, const char* ascii_dest)
 	return CeCopyFileA(ascii_source, ascii_dest, false);
 }
 
-#define ANYFILE_BUFFER_SIZE (16*1024)
+#define ANYFILE_BUFFER_SIZE (64*1024)
 
 static bool anyfile_copy(char* source_ascii, char* dest_ascii, const char* name, size_t* bytes_copied)
 {
@@ -124,7 +124,7 @@ static bool anyfile_copy(char* source_ascii, char* dest_ascii, const char* name,
 			goto exit;
 		}
 
-		if (bytes_written != bytes_read)
+		if ((int)bytes_written != (int)bytes_read)
 		{
 			fprintf(stderr, "%s: Only wrote %i bytes of %i to destination file '%s'\n", name, 
 					bytes_written, bytes_read, dest_ascii);
@@ -169,11 +169,11 @@ int main(int argc, char** argv)
 	if (!handle_parameters(argc, argv, &source, &dest))
 		goto exit;
 
-        if ((connection = rapi_connection_from_path(devpath)) == NULL)
+        if ((connection = rapi_connection_from_name(dev_name)) == NULL)
         {
           fprintf(stderr, "%s: Could not find configuration at path '%s'\n", 
                   argv[0],
-                  devpath?devpath:"(Default)");
+                  dev_name?dev_name:"(Default)");
           goto exit;
         }
         rapi_connection_select(connection);
