@@ -1,4 +1,4 @@
-/* $Id: pls.c 2348 2006-04-05 14:58:44Z twogood $ */
+/* $Id: pls.c 3321 2008-03-20 09:44:20Z mark_ellis $ */
 #include "pcommon.h"
 #include <rapi.h>
 #include <synce_log.h>
@@ -7,7 +7,7 @@
 #include <string.h>
 #include <unistd.h>
 
-char* devpath = NULL;
+char* dev_name = NULL;
 
 static bool numeric_file_attributes = false;
 static bool show_hidden_files = false;
@@ -17,7 +17,7 @@ static void show_usage(const char* name)
 	fprintf(stderr,
 			"Syntax:\n"
 			"\n"
-			"\t%s [-a] [-d LEVEL] [-p DEVPATH] [-h] [-n] [DIRECTORY]\n"
+			"\t%s [-a] [-d LEVEL] [-p DEVNAME] [-h] [-n] [DIRECTORY]\n"
 			"\n"
 			"\t-a        Show all files including those marked as hidden\n"
 			"\t-d LEVEL  Set debug log level\n"
@@ -26,7 +26,7 @@ static void show_usage(const char* name)
 			"\t              2 - Errors and warnings\n"
 			"\t              3 - Everything\n"
 			"\t-h         Show this help message\n"
-                        "\t-p DEVPATH Device path\n"
+                        "\t-p DEVNAME Mobile device name\n"
 			"\t-n         Show numeric value for file attributes\n"
 			"\tDIRECTORY  The remote directory where you want to list files\n",
 			name);
@@ -46,7 +46,7 @@ static bool handle_parameters(int argc, char** argv, char** path)
 				break;
 					
                         case 'p':
-                                devpath = optarg;
+                                dev_name = optarg;
                                 break;
 			
               		case 'd':
@@ -161,7 +161,7 @@ static bool print_entry(CE_FIND_DATA* entry)
 	 */
 
 	filename = wstr_to_current(entry->cFileName);
-        printf(filename);
+        printf("%s", filename);
 	wstr_free_string(filename);
 	if (entry->dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
 		printf("/");
@@ -178,8 +178,6 @@ static bool list_matching_files(WCHAR* wide_path)
 	DWORD file_count = 0;
 	unsigned i;
 
-	synce_trace_wstr(wide_path);
-	wide_path = adjust_remote_path(wide_path, true);
 	synce_trace_wstr(wide_path);
 
 	result = CeFindAllFiles(
@@ -190,6 +188,11 @@ static bool list_matching_files(WCHAR* wide_path)
 
 	if (!result)
 		goto exit;
+
+	if (file_count == 0) {
+		fprintf(stderr, "No such file or directory");
+		goto exit;
+	}
 	
 	for (i = 0; i < file_count; i++)
 		print_entry(find_data + i);
@@ -231,18 +234,19 @@ int main(int argc, char** argv)
 	char* path = NULL;
 	WCHAR* wide_path = NULL;
 	HRESULT hr;
-	
+
 	if (!handle_parameters(argc, argv, &path))
 		goto exit;
 
-        if ((connection = rapi_connection_from_path(devpath)) == NULL)
+        if ((connection = rapi_connection_from_name(dev_name)) == NULL)
         {
           fprintf(stderr, "%s: Could not find configuration at path '%s'\n", 
                   argv[0],
-                  devpath?devpath:"(Default)");
+                  dev_name?dev_name:"(Default)");
           goto exit;
         }
         rapi_connection_select(connection);
+
 	hr = CeRapiInit();
 
 	if (FAILED(hr))
@@ -267,6 +271,7 @@ int main(int argc, char** argv)
 		char new_path[MAX_PATH];
 		snprintf(new_path, sizeof(new_path), "%s*", path);
 		wide_path = wstr_from_current(new_path);
+		wide_path = adjust_remote_path(wide_path, true);
 
 		if (!list_matching_files(wide_path))
 			goto exit;
