@@ -1,4 +1,4 @@
-/* $Id: pmv.c 2348 2006-04-05 14:58:44Z twogood $ */
+/* $Id: pmv.c 3321 2008-03-20 09:44:20Z mark_ellis $ */
 #include "pcommon.h"
 #include <rapi.h>
 #include <synce_log.h>
@@ -7,14 +7,14 @@
 #include <string.h>
 #include <unistd.h>
 
-char* devpath = NULL;
+char* dev_name = NULL;
 
 static void show_usage(const char* name)
 {
 	fprintf(stderr,
 			"Syntax:\n"
 			"\n"
-			"\t%s [-d LEVEL] [-p DEVPATH] [-h] SOURCE DESTINATION\n"
+			"\t%s [-d LEVEL] [-p DEVNAME] [-h] SOURCE DESTINATION\n"
 			"\n"
 			"\t-d LEVEL     Set debug log level\n"
 			"\t                 0 - No logging (default)\n"
@@ -22,7 +22,7 @@ static void show_usage(const char* name)
 			"\t                 2 - Errors and warnings\n"
 			"\t                 3 - Everything\n"
 			"\t-h           Show this help message\n"
-                        "\t-p DEVPATH   Device path\n"
+                        "\t-p DEVNAME   Mobile device name\n"
 			"\tSOURCE       The current filename\n"
 			"\tDESTINATION  The new filename\n",
 			name);
@@ -42,7 +42,7 @@ static bool handle_parameters(int argc, char** argv, char** source, char** dest)
 				break;
 			
                         case 'p':
-                                devpath = optarg;
+                                dev_name = optarg;
                                 break;
 			
 			case 'h':
@@ -80,11 +80,11 @@ int main(int argc, char** argv)
 	if (!handle_parameters(argc, argv, &source, &dest))
 		goto exit;
 
-        if ((connection = rapi_connection_from_path(devpath)) == NULL)
+        if ((connection = rapi_connection_from_name(dev_name)) == NULL)
         {
           fprintf(stderr, "%s: Could not find configuration at path '%s'\n", 
                   argv[0],
-                  devpath?devpath:"(Default)");
+                  dev_name?dev_name:"(Default)");
           goto exit;
         }
         rapi_connection_select(connection);
