@@ -1,4 +1,4 @@
-/* $Id: prun.c 2348 2006-04-05 14:58:44Z twogood $ */
+/* $Id: prun.c 3321 2008-03-20 09:44:20Z mark_ellis $ */
 #include "pcommon.h"
 #include "rapi.h"
 #include <synce_log.h>
@@ -7,14 +7,14 @@
 #include <string.h>
 #include <unistd.h>
 
-char* devpath = NULL;
+char* dev_name = NULL;
 
 static void show_usage(const char* name)
 {
 	fprintf(stderr,
 			"Syntax:\n"
 			"\n"
-			"\t%s [-d LEVEL] [-p DEVPATH] [-h] PROGRAM [--] [PARAMETERS]\n"
+			"\t%s [-d LEVEL] [-p DEVNAME] [-h] PROGRAM [--] [PARAMETERS]\n"
 			"\n"
 			"\t-d LEVEL    Set debug log level\n"
 			"\t                0 - No logging (default)\n"
@@ -22,7 +22,7 @@ static void show_usage(const char* name)
 			"\t                2 - Errors and warnings\n"
 			"\t                3 - Everything\n"
 			"\t-h          Show this help message\n"
-                        "\t-p DEVPATH  Device path\n"
+                        "\t-p DEVNAME  Mobile device name\n"
 			"\tPROGRAM     The program you want to run\n"
       "\t--          Needed if PARAMETERS begin with a dash ('-')\n"
 			"\tPARAMETERS  Parameters to the program\n",
@@ -43,7 +43,7 @@ static bool handle_parameters(int argc, char** argv, char** program, char** para
 				break;
 			
                         case 'p':
-                                devpath = optarg;
+                                dev_name = optarg;
                                 break;
 
 			case 'h':
@@ -84,11 +84,11 @@ int main(int argc, char** argv)
 	if (!handle_parameters(argc, argv, &program, &parameters))
 		goto exit;
 
-        if ((connection = rapi_connection_from_path(devpath)) == NULL)
+        if ((connection = rapi_connection_from_name(dev_name)) == NULL)
         {
           fprintf(stderr, "%s: Could not find configuration at path '%s'\n", 
                   argv[0],
-                  devpath?devpath:"(Default)");
+                  dev_name?dev_name:"(Default)");
           goto exit;
         }
         rapi_connection_select(connection);
